// based css:
// https://bazaar.launchpad.net/~lightdm-gtk-greeter-team/lightdm-gtk-greeter/trunk/view/head:/data/sample-lightdm-gtk-greeter.css

/************************
 * LightDM GTK+ Greeter *
 ************************/
// the panel widget at the top
#panel_window {
  background-color: transparent;
  color: $white;
  box-shadow: none;
  border-color: transparent;
  // font-weight: bold;

  // the menubars/menus of the panel, i.e. indicators
  menubar,
  separator {
    background-color: transparent;
    border: none;
    box-shadow: none;
  }

  separator {
    padding: 0 4px;

    &:first-child { padding: 0 8px; }
  }

  menubar > menuitem {
    color: on($scrim-alt, secondary);

    &:hover { color: on($scrim-alt); }

    &:disabled label { color: on($scrim-alt, secondary-disabled); }
  }

  menu {
    border-radius: 0;
    box-shadow: none;
    border: 1px solid $solid-border;
  }
}

// the login window
#login_window,
#shutdown_dialog,
#restart_dialog {
  margin: 0;
  border-radius: $corner-radius;
  box-shadow: none;
  background-color: $surface;

  menu {
    border-radius: 0;
    box-shadow: none;
    border: 1px solid $solid-border;
  }
}

// the top half of the login-window, in GtkDialog terms, the content
#content_frame {
  padding-bottom: 28px - 12px; // take into account the hard-coded 12px margin_bottom
}

// #login_window {
//   // the user-combobox
//   // #user_combobox button {}
//
//   // the entries, one for the username, one for the password
//   // entry {}
// }

// the buttons, alternatively this could also be done with a simple ".lightdm-gtk-greeter button"
// #login_window,
// #shutdown_dialog,
// #restart_dialog {
//   button {}
// }

// .lightdm-gtk-greeter button {}

// the user's avatar box
// #user_image {
//   border-radius: $corner-radius;
// }

// the border around the user's avatar box
// #user_image_border {
//   border-radius: $corner-radius;
// }

// the lower half of the login-window, in GtkDialog terms the buttonbox or action area
#buttonbox_frame {
  padding-top: 24px;

  > box,
  > buttonbox { margin: -16px; }

  button {
    @extend %button-flat;

    &:not(:disabled) { color: $primary; }
  }
}

// the shutdown button
// #shutdown_button {}

// the restart button
// #restart_button {}

// the warning, in case a wrong password is entered or something else goes wrong according to PAM
// #greeter_infobar {
//   font-weight: bold;
// }
