// Links
.shell-link {
  border-radius: $material-radius;
  color: $link;
  background-color: transparent;
  &:hover {
    color: $link;
    background-color: rgba($link, 0.3 / 2);
  }
  &:active {
    color: $link;
    background-color: rgba($link, 0.3);
  }
}

// Outline for low res icons
.lowres-icon {
  icon-shadow: 0 1px 2px rgba(black, 0.1);
}

// Dropshadow for large icons
.icon-dropshadow {
  icon-shadow: 0 2px 5px rgba(black, 0.15);
}
