// Default Theme Color Palette

// Red
$red-light: #F44336;
$red-dark: #E53935;

// Pink
$pink-light: #F06292;
$pink-dark: #EC407A;

// Purple
$purple-light: #BA68C8;
$purple-dark: #AB47BC;

// Blue
$blue-light: #3281EA;
$blue-dark: #1A73E8;

// Teal
$teal-light: #4DB6AC;
$teal-dark: #009688;

// Green
$green-light: #66BB6A;
$green-dark: #4CAF50;
$sea-light: #81C995;
$sea-dark: #0F9D58;

// Yellow
$yellow-light: #FBC02D;
$yellow-dark: #FFD600;

// Orange
$orange-light: #FB8C00;
$orange-dark: #F57C00;

// Grey
$grey-050: #FAFAFA;
$grey-100: #F2F2F2;
$grey-150: #EEEEEE;
$grey-200: #DDDDDD;
$grey-250: #CCCCCC;
$grey-300: #BFBFBF;
$grey-350: #A0A0A0;
$grey-400: #9E9E9E;
$grey-450: #868686;
$grey-500: #727272;
$grey-550: #555555;
$grey-600: #464646;
$grey-650: #3C3C3C;
$grey-700: #2C2C2C;
$grey-750: #242424;
$grey-800: #212121;
$grey-850: #121212;
$grey-900: #0F0F0F;
$grey-950: #030303;

// White
$white: #FFFFFF;

// Black
$black: #000000;

// Windows Button
$button-close: #fd5f51;
$button-max: #38c76a;
$button-min: #fdbe04;
