// Default Theme Color Palette

// Red
$red-light: #d4878f;
$red-dark: #c35b65;

// Pink
$pink-light: #dc98b1;
$pink-dark: #cd7092;

// Purple
$purple-light: #c89dbf;
$purple-dark: #b57daa;

// Blue
$blue-light: #89a3c2;
$blue-dark: #5e81ac;

// Teal
$teal-light: #83b9b8;
$teal-dark: #63a6a5;

// Green
$green-light: #a0c082;
$green-dark: #82ac5d;
$sea-light: #8bd9b4;
$sea-dark: #60a684;

// Yellow
$yellow-light: #eac985;
$yellow-dark: #e4b558;

// Orange
$orange-light: #dca493;
$orange-dark: #d08770;

// Grey
$grey-050: #f8fafc;
$grey-100: #f0f1f4;
$grey-150: #eaecf0;
$grey-200: #d9dce3;
$grey-250: #c4c9d4;
$grey-300: #b5bcc9;
$grey-350: #929cb0;
$grey-400: #8e99ae;
$grey-450: #74819a;
$grey-500: #616d85;
$grey-550: #464f62;
$grey-600: #3a4150;
$grey-650: #333a47;
$grey-700: #242932;
$grey-750: #1e222a;
$grey-800: #1c1f26;
$grey-850: #0f1115;
$grey-900: #0d0e11;
$grey-950: #020203;

// White
$white: #ffffff;

// Black
$black: #000000;

// Button
$button-close: #bf616a;
$button-max: #a3be8c;
$button-min: #ebcb8b;
