/* Entries */

StEntry {
  min-height: $medium-size;
  padding: 0 8px;
  border-radius: if($corner_style == 'circular', $circular-radius, $material-radius);
  border-width: 0;
  selection-background-color: rgba($primary, 0.35) !important;
  selected-color: $primary !important;
  @include font(subheading);
  @include entry(normal);
  &:hover { @include entry(hover); }
  &:focus { @include entry(focus); }
  &:insensitive { @include entry(insensitive); }
  StIcon.capslock-warning {
    icon-size: $base-icon-size;
    warning-color: $warning;
    padding: 0 4px;
  }
  StIcon.peek-password {
    icon-size: $base-icon-size;
    padding: 0 4px;
  }
  StLabel.hint-text {
    margin-left: 2px;
    color: $text-disabled;
  }
}
