/* Header bar */
@import "headerbar-urlbar.css";
@import "headerbar-private-urlbar.css";
@namespace xul "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

/* Headerbar */
#nav-bar {
	padding: 4px 8px !important;
}

/* Headerbar CSD colors */
:root[tabsintitlebar] #nav-bar {
  background-color: var(--toolbar-bgcolor);
  background-image: var(--toolbar-bgimage);
	border: none !important;
	border-bottom: 0 solid var(--gnome-headerbar-border-color) !important;
	box-shadow: none !important;
}
:root[tabsintitlebar] #nav-bar:-moz-window-inactive {
	border-bottom: 0 solid var(--gnome-inactive-headerbar-border-color) !important;
	box-shadow: none !important;
}
