/* OSD */

$osd_levelbar_height: 4px;

.osd-window {
  @extend %osd_panel;
  text-align: center;
  font-weight: bold;
  spacing: $space-size * 2;
  padding: $space-size * 2 $space-size * 3;
  margin-bottom: 8em;
  border-radius: $circular-radius;

  & > * { spacing: 8px; }

  StIcon {
    icon-size: 32px;
  }

  .osd-monitor-label { font-size: 3em; }

  StLabel {
    &:ltr { margin-right: $space-size; }
    &:rtl { margin-left: $space-size; }
  }

  .level {
    height: $osd_levelbar_height;
    min-width: 160px;
    margin-bottom: 4px;
    &:first-child { margin-bottom: 0px; }

    -barlevel-height: $osd_levelbar_height;
    -barlevel-background-color: rgba($primary, 0.3);
    -barlevel-active-background-color: $primary;
    -barlevel-overdrive-color: $destructive;
    -barlevel-overdrive-separator-width: 3px;
    -barlevel-border-width: 0;

    &:ltr { margin-right: $space-size; }
    &:rtl { margin-left: $space-size; }
  }
}

// Monitor number label
.osd-monitor-label {
  @extend %osd_panel;
  border-radius: $window-radius;
  font-size: 3em;
  font-weight: bold;
  margin: $margin-size * 3;
  text-align: center;
  min-width: 1.3em;
}

/* Pad OSD */
.pad-osd-window {
  padding: 32px;
  background-color: transparentize(black, 0.2);
  border: none;

  .pad-osd-title-box { spacing: $space-size * 2; }
  .pad-osd-title-menu-box { spacing: $space-size; }
}

.combo-box-label {
  width: 15em;
}

.resize-popup {
  @extend %osd_panel;
  border-radius: $window-radius;
}
