gtk-color-scheme = "theme-default-color:#212121"
gtk-color-scheme = "theme-purple-color:#212121"
gtk-color-scheme = "theme-pink-color:#212121"
gtk-color-scheme = "theme-red-color:#212121"
gtk-color-scheme = "theme-orange-color:#212121"
gtk-color-scheme = "theme-yellow-color:#212121"
gtk-color-scheme = "theme-green-color:#212121"
gtk-color-scheme = "theme-grey-color:#212121"
gtk-color-scheme = "theme-nord-color:#212121"
gtk-color-scheme = "theme-default-dark-color:#212121"
gtk-color-scheme = "theme-purple-dark-color:#212121"
gtk-color-scheme = "theme-pink-dark-color:#212121"
gtk-color-scheme = "theme-red-dark-color:#212121"
gtk-color-scheme = "theme-orange-dark-color:#212121"
gtk-color-scheme = "theme-yellow-dark-color:#212121"
gtk-color-scheme = "theme-green-dark-color:#212121"
gtk-color-scheme = "theme-grey-dark-color:#212121"
gtk-color-scheme = "theme-nord-dark-color:#212121"
