@namespace xul url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

:root[tabsintitlebar][sizemode="maximized"] #titlebar .titlebar-buttonbox-container {
    display: none !important;
}

:root[tabsintitlebar][sizemode="maximized"] #nav-bar {
    padding-left: 3px !important;
}
