$variant: 'dark';
$topbar: 'dark';
$compact: 'false';

@import '../../_sass/variables';
@import '../../_sass/colors';
@import '../../_sass/gnome-shell/drawing';
@import '../../_sass/gnome-shell/common';
@import '../../_sass/gnome-shell/widgets-44-0';
@import '../../_sass/gnome-shell/extensions-40-0';
