/* Network Dialogs */
.nm-dialog {
  max-height: 34em;
  min-height: 31em;
  min-width: 32em;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 24px;
}

.nm-dialog-airplane-box { spacing: 12px; }

.nm-dialog-airplane-headline {
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text { color: $text; }

// header
.nm-dialog-header {
  font-weight: bold;
}
.nm-dialog-header-icon {
  icon-size: 32px
}
.nm-dialog-header-hbox { spacing: 10px; }

// list of networks
.nm-dialog-scroll-view {
  border: none;
  background-color: $secondary-fill;
  border-radius: $material-radius;
  padding: $space-size * 2;
  padding-right: 0;
}

// list item
.nm-dialog-item {
  font-size: 1em;
  border-bottom: none;
  border-radius: $material-radius - $space-size;
  padding: $space-size * 2;
  spacing: 0px;

  &:hover, &:focus { background-color: $secondary-fill; }

  &:active { background-color: $track; }

  &:selected {
    background-color: $primary;
    color: on(dark);
  }
}

// icons in list
.nm-dialog-icon { icon-size: $base-icon-size; }
.nm-dialog-icons { spacing: $space-size * 2; }

// no networks
.no-networks-label { color: $text-disabled; }
.no-networks-box { spacing: $space-size; }
