$variant: 'dark';
$topbar: 'dark';
$compact: 'false';

@import '../../_sass/variables';
@import '../../_sass/colors';
@import '../../_sass/gtk/drawing-3.20';
@import '../../_sass/gtk/common-3.20';
@import '../../_sass/gtk/apps-3.22';
@import '../../_sass/gtk/colors-public';
